@@ -13,11 +13,10 @@ You should have received a copy of the GNU Lesser General Public License
 along with this library; if not, write to the Free Software Foundation, Inc.,
 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 **********/
-// Copyright (c) 1996-2009 Live Networks, Inc.  All rights reserved.
+// Copyright (c) 1996-2010 Live Networks, Inc.  All rights reserved.
 // Basic Usage Environment: for a simple, non-scripted, console application
 // Implementation
 
-#ifndef IMN_PIM
 #include "BasicUsageEnvironment.hh"
 #include <stdio.h>
 
@@ -33,7 +32,7 @@ BasicUsageEnvironment::BasicUsageEnvironment(TaskScheduler& taskScheduler)
   if (!initializeWinsockIfNecessary()) {
     setResultErrMsg("Failed to initialize 'winsock': ");
     reportBackgroundError();
-    exit(1);
+    abort();
   }
 #endif
 }
@@ -78,5 +77,3 @@ UsageEnvironment& BasicUsageEnvironment::operator<<(void* p) {
 	fprintf(stderr, "%p", p);
 	return *this;
 }
-#endif
-
